==> adequate_0.15.13.tar.xz: go/apt.go <==
// This file is part of the adequate Debian-native package, and is available
// under the Expat license. For the full terms please see debian/copyright.

package main

import (
	"bufio"
	"fmt"
	"io"
	"log"
	"os"
	"regexp"
	"syscall"
)

const pendingPath = "/var/lib/adequate/pending"

func aptHookIsEnabled() bool {
	var enabled, defined bool

	reader := bufio.NewReader(os.Stdin)
loop:
	for {
		line, err := reader.ReadString('\n')

		if err == io.EOF {
			break loop
		} else if err != nil {
			log.Fatal("Read error: ", err)
		}

		switch line {
		case "Adequate::Enabled=true\n":
			enabled = true
			defined = true
		case "Adequate::Enabled=false\n":
			enabled = false
			defined = true
		case "\n":
			break loop
		}
	}

	if !defined {
		log.Println("apt hook is not enabled")
		return false
	}
	return enabled
}

var re = regexp.MustCompile("/^(" + nonSpaceToken + ")" + spaceToken + nonSpaceToken + spaceToken +
	nonSpaceToken + spaceToken + nonSpaceToken + spaceToken + "/.+_([a-z0-9]+)[.]deb$/")

func readPkgsFromStdin() []string {
	var pkgs []string

	reader := bufio.NewReader(os.Stdin)
	for {
		line, err := reader.ReadString('\n')
		if err == io.EOF {
			break
		} else if err != nil {
			log.Fatal("Read error: ", err)
		}

		m := re.FindStringSubmatch(line)
		if len(m) != 3 {
			continue
		}
		pkg, arch := m[1], m[2]
		if arch != "all" {
			pkg = pkg + ":" + arch
		}
		pkgs = append(pkgs, pkg)
	}

	return pkgs
}

type pendingHandler struct {
	fi *os.File
}

func newPendingHandler() (*pendingHandler, error) {
	fi, err := os.OpenFile(pendingPath, os.O_APPEND|os.O_RDWR|os.O_CREATE, 0666)
	if err != nil {
		return nil, fmt.Errorf("%s: %w", pendingPath, err)
	}
	if err := syscall.Flock(int(fi.Fd()), syscall.LOCK_EX); err != nil {
		return nil, fmt.Errorf("%s: %w", pendingPath, err)
	}
	return &pendingHandler{
		fi: fi,
	}, nil
}

func (ph *pendingHandler) read() ([]string, error) {
	return readLines(ph.fi)
}

func (ph *pendingHandler) truncatePendingOrDie() {
	ph.writePendingOrDie(nil)
}

func (ph *pendingHandler) writePendingOrDie(pkgs []string) {
	if ph.fi == nil {
		log.Fatal("writePendingOrDie() called with nil file handler")
	}
	if err := ph.fi.Truncate(0); err != nil {
		log.Fatalf("Failed to truncate %s: %v", pendingPath, err)
	}
	if _, err := ph.fi.Seek(0, 0); err != nil {
		log.Fatalf("Failed to seek %s: %v", pendingPath, err)
	}

	for _, pkg := range pkgs {
		if _, err := ph.fi.WriteString(pkg + "\n"); err != nil {
			log.Fatalf("Failed to write %s: %v", pendingPath, err)
		}
	}
}

func (ph *pendingHandler) cleanup() error {
	if err := syscall.Flock(int(ph.fi.Fd()), syscall.LOCK_UN); err != nil {
		return err
	}
	return ph.fi.Close()
}

==> adequate_0.15.14.tar.xz: go/apt.go <==
// This file is part of the adequate Debian-native package, and is available
// under the Expat license. For the full terms please see debian/copyright.

package main

import (
	"bufio"
	"fmt"
	"io"
	"log"
	"os"
	"regexp"
	"syscall"
)

const pendingPath = "/var/lib/adequate/pending"

func aptHookReader() *bufio.Reader {
	return bufio.NewReader(os.Stdin)
}

func aptHookIsEnabled(reader *bufio.Reader) bool {
	var enabled, defined bool

loop:
	for {
		line, err := reader.ReadString('\n')

		if err == io.EOF {
			break loop
		} else if err != nil {
			log.Fatal("Read error: ", err)
		}

		// This is what debconf feeds us. It's *not* the text from the
		// apt hook file.
		switch line {
		case "Adequate::Enabled=true\n":
			enabled = true
			defined = true
		case "Adequate::Enabled=false\n":
			enabled = false
			defined = true
		case "\n":
			break loop
		}
	}

	if !defined {
		log.Println("apt hook is not enabled")
		return false
	}
	return enabled
}

var re = regexp.MustCompile("/^(" + nonSpaceToken + ")" + spaceToken + nonSpaceToken + spaceToken +
	nonSpaceToken + spaceToken + nonSpaceToken + spaceToken + "/.+_([a-z0-9]+)[.]deb$/")

func readPkgsFromStdin() []string {
	var pkgs []string

	reader := bufio.NewReader(os.Stdin)
	for {
		line, err := reader.ReadString('\n')
		if err == io.EOF {
			break
		} else if err != nil {
			log.Fatal("Read error: ", err)
		}

		m := re.FindStringSubmatch(line)
		if len(m) != 3 {
			continue
		}
		pkg, arch := m[1], m[2]
		if arch != "all" {
			pkg = pkg + ":" + arch
		}
		pkgs = append(pkgs, pkg)
	}

	return pkgs
}

type pendingHandler struct {
	fi *os.File
}

func newPendingHandler() (*pendingHandler, error) {
	fi, err := os.OpenFile(pendingPath, os.O_APPEND|os.O_RDWR|os.O_CREATE, 0666)
	if err != nil {
		return nil, fmt.Errorf("%s: %w", pendingPath, err)
	}
	if err := syscall.Flock(int(fi.Fd()), syscall.LOCK_EX); err != nil {
		return nil, fmt.Errorf("%s: %w", pendingPath, err)
	}
	return &pendingHandler{
		fi: fi,
	}, nil
}

func (ph *pendingHandler) read() ([]string, error) {
	return readLines(ph.fi)
}

func (ph *pendingHandler) truncatePendingOrDie() {
	ph.writePendingOrDie(nil)
}

func (ph *pendingHandler) writePendingOrDie(pkgs []string) {
	if ph.fi == nil {
		log.Fatal("writePendingOrDie() called with nil file handler")
	}
	if err := ph.fi.Truncate(0); err != nil {
		log.Fatalf("Failed to truncate %s: %v", pendingPath, err)
	}
	if _, err := ph.fi.Seek(0, 0); err != nil {
		log.Fatalf("Failed to seek %s: %v", pendingPath, err)
	}

	for _, pkg := range pkgs {
		if _, err := ph.fi.WriteString(pkg + "\n"); err != nil {
			log.Fatalf("Failed to write %s: %v", pendingPath, err)
		}
	}
}

func (ph *pendingHandler) cleanup() error {
	if err := syscall.Flock(int(ph.fi.Fd()), syscall.LOCK_UN); err != nil {
		return err
	}
	return ph.fi.Close()
}
